@@ -15,11 +15,10 @@ namespace SebastianBergmann\Comparator;
 class Author
 {
     // the order of properties is important for testing the cycle!
-    public $books = [];
+    public array $books = [];
+    private string $name;
 
-    private $name = '';
-
-    public function __construct($name)
+    public function __construct(string $name)
     {
         $this->name = $name;
     }
